@@ -63,16 +63,20 @@ sub ref {
 
 foreach my $sym (keys %UNIVERSAL::) {
 	no strict 'refs';
+
 	next if $sym eq 'ref::';
 	next if defined &$sym;
+
+	local $@;
+
 	*{$sym} = eval "sub {
 		if ( Scalar::Util::blessed(\$_[0]) ) {
-			unshift \@_, \$sym;
+			unshift \@_, '$sym';
 			goto \$vivify_and_call;
 		} else {
 			shift->SUPER::$sym(\@_);
 		}
-	}";
+	}" || die $@;
 }
 
 sub AUTOLOAD {
